#!/bin/sh

# Script genrico para preparar herramientas de DocBook y configurar.
# Esta fuente se cede al dominio pblico 2002. No se ofrecen garantas.
# structio-devel@lists.sourceforge.net
# Se aprecia que la fuente sea citada:
# http://structio.sourceforge.net/

# Leyendo variables de configuracin
if (test ! -f confv.sh) then {
        cp confv.empty confv.sh
} fi;

. ./confv.sh

echo "Configurando $PROYECTO $PRY_VERSION";

# Leyendo funciones para ayudar en configuracin
. herram/confaux.sh
. herram/misc.sh

# Reconociendo opciones
parseop "$@";

if (test "$prefix" != "") then {
        INSBIN="$prefix/bin";
        changeVar INSBIN 1;
        INSDOC="$prefix/share/doc/$PROYECTO";
        changeVar INSDOC 1;
} fi;

# Chequeando caractersticas
check "JADE" "" "test -x \$JADE" `which jade 2> /dev/null` `which openjade 2> /dev/null`
check "JADETEX" "" "test -x \$JADETEX" `which jadetex 2> /dev/null`
check "PDFJADETEX" "" "test -x \$PDFJADETEX" `which pdfjadetex 2> /dev/null`
check "XMLLINT" "" "test -x \$XMLLINT" `which xmllint`
check "XSLTPROC" "" "test -x \$XSLTPROC" `which xsltproc`
verxsltproc=`xsltproc -V | head -n 1 | sed -e "s/.*libxslt \([0-9]*\) .*/\1/g"`
if (test "$verxsltproc" -lt "10019") then {
	echo "Se requiere xsltproc 1.0.19 o superior (versiones anteriores presentan errores con imagenes de DocBook XML 4.1.2)";
	exit 1;
} fi;
check "DVIPS" "" "test -x \$DVIPS" `which dvips 2> /dev/null`
check "PS2PDF" "" "test -x \$PS2PDF" `which ps2pdf 2> /dev/null`

check "DOCBOOK_XML_DIR" "" "test -f \$DOCBOOK_XML_DIR/docbookx.dtd" "/usr/local/share/xml/docbook/4.1.2" "/usr/share/sgml/docbook/dtd/xml/4.1.2"
check "DOCBOOK_DSSSL_HTML" "" "test -f \$DOCBOOK_DSSSL_HTML/docbook.dsl" "/usr/local/share/sgml/docbook/dsssl/modular/html/" "/usr/share/sgml/docbook/stylesheet/dsssl/modular/html"
check "DOCBOOK_DSSSL_PRINT" "" "test -f \$DOCBOOK_DSSSL_PRINT/docbook.dsl" "/usr/local/share/sgml/docbook/dsssl/modular/print" "/usr/share/sgml/docbook/stylesheet/dsssl/modular/print"
check "DOCBOOK_XSL" "" "test -f \$DOCBOOK_XSL/html/docbook.xsl" "/usr/local/share/xml/docbook-xsl" "/usr/share/sgml/docbook/stylesheet/xsl/nwalsh"
v=`grep VERSION $DOCBOOK_XSL/VERSION | sed -e "s/^.*VERSION.>\([0-9]*[.][0-9]*\)[.].*$/\1/g"`
if (test "$v" = "") then {
	echo " Falta archivo VERSION en directorio $DOCBOOK_XSL";
	exit 1;
} 
elif (ltf "$v" "1.56") then {
	echo "Se requieren hojas de estilo versin 1.56 o posterior";
	exit 1;
} fi;
check "COLLATEINDEX" "" "test -f \$COLLATEINDEX" "/usr/local/share/sgml/docbook/dsssl/modular/bin/collateindex.pl" "/usr/share/sgml/docbook/dsssl/nwalsh-modular/bin/collateindex.pl" "/usr/bin/collateindex.pl" `which collateindex.pl`

check "CONVERT" "" "test -x \$CONVERT" `which convert 2> /dev/null`

check "SED" "" "test -x \$SED" `which sed 2> /dev/null`
check "AWK" "" "test -x \$AWK" `which awk 2> /dev/null`

FECHA_ACT=`date`;
changeVar FECHA_ACT 1;
m=`date "+%m" | sed -e "s/01/Enero/;s/02/Febrero/;s/03/Marzo/;s/04/Abril/;s/05/Mayo/;s/06/Junio/;s/07/Julio/;s/08/Agosto/;s/09/Septiembre/;s/10/Octubre/;s/11/Noviembre/;s/12/Diciembre/"`
a=`date "+%Y"`
MES_ACT="$m de $a";
changeVar MES_ACT 1;
 
echo "Guardando variables de configuracin";
changeConfv;

echo "Generando Make.inc";

echo "# Algunas variables para el Makefile" > Make.inc;
echo "# Este archivo es generado automticamente por conf.sh. No editar" >> Make.inc;
echo "" >> Make.inc

# Adding configuration variables to Make.inc
addMakeConfv Make.inc;
echo "PREFIX=$prefix" >> Make.inc

echo "Generando confv.xml"
echo "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>" > confv.xml
echo "<!-- Variables de configuracin  -->" >> confv.xml
echo "<!-- Este archivo es generado automticamente por conf.sh. No editar -->" >> confv.xml

addXMLConfv confv.xml;

echo "Creando directorios auxiliares"
mkdir -p html
mkdir -p imp

echo "Configuracin terminada";

