
# Common rules to generate HTML, PostScript and PDF versions of a DocBook document
# Released to the public domain. structio-devel@lists.sourceforge.net

# Variables required

# Tools
#DOCBOOK_XML_DIR Is path of DocBook XML DTD
#XSLTPROC XSLT Processor xsltproc
#XMLLINT XML validator xmllint
#JADE Path to Jade or OpenJade
#JADETEX Path to jadetex
#PDFJADETEX Path to jadetex

# Of the particular project
# PROYECTO With project name and name of main file (extension .xml)
# SOURCES Sources including $PROYECTO.xml
# IMAGES 
# HTML_TARGETS Targets for HTML
# HTML_DIR Directory where HTML will be generated
# XSLT_HTML Custom XSLT for HTML estilohtml.xsl
# PRINT_DIR Directory where PostScript and PDF will be generated
# DSSSL_PRINT DSSSL custom style for printing
# DOCBOOK_DSSSL_PRINT Directory with stylesheets DSSSL to print
# OTHER_HTML Other things to do after generating HTML
# INDEX file name where index will be generated, if NULL no index is generated

valida: $(SOURCES) $(PROYECTO)-4.1.2.xml
	$(XMLLINT) --valid $(PROYECTO)-4.1.2.xml

$(PROYECTO)-4.1.2.xml: $(PROYECTO).xml
	sed -e "s|DOCTYPE \\([A-Za-z0-9_]*\\) [-\" A-Za-z0-9_/.]*|DOCTYPE \\1 PUBLIC \"-//OASIS//DTD DocBook XML V4.1.2//EN\" \"$(DOCBOOK_XML_DIR)/docbookx.dtd\"|g" $(PROYECTO).xml > $@

# To generate HTML with xsltproc
$(HTML_TARGETS): $(INDEX) $(SOURCES) $(IMAGES) $(XSLT_HTML) $(PROYECTO)-4.1.2.xml
	mkdir -p $(HTML_DIR)
	for i in $(IMAGES) ; do cp $$i $(HTML_DIR)/`basename $$i`; done 
	bp=`pwd`;cd $(HTML_DIR) && rm -f *html && $(XSLTPROC) --catalogs --nonet $$bp/$(XSLT_HTML) $$bp/$(PROYECTO)-4.1.2.xml 
	rm -f $(PROYECTO)-4.1.2.xml	
	$(OTHER_HTML)

# Possible rule to generate HTML with OpenJade
#$(HTML_DIR)/$(PROYECTO).html: $(SOURCES)
#	-cd $(HTML_DIR) && rm -f * && $(JADE) -D .. -D $(DOCBOOK_HTML) -t sgml -ihtml -d estilo.dsl#html $(PROYECTO).xml

$(PROYECTO)-$(PRY_VERSION)_html.tar.gz: $(HTML_TARGETS)
	tar cvfz $(PROYECTO)-$(PRY_VERSION)_html.tar.gz $(HTML_DIR)

$(PRINT_DIR)/$(PROYECTO)-$(PRY_VERSION).pdf: $(PRINT_DIR)/$(PROYECTO).pdf
	cp $(PRINT_DIR)/$(PROYECTO).pdf $(PRINT_DIR)/$(PROYECTO)-$(PRY_VERSION).pdf

$(PRINT_DIR)/$(PROYECTO)-$(PRY_VERSION).ps.gz: $(PRINT_DIR)/$(PROYECTO).ps
	cp $(PRINT_DIR)/$(PROYECTO).ps $(PRINT_DIR)/$(PROYECTO)-$(PRY_VERSION).ps
	gzip $(PRINT_DIR)/$(PROYECTO)-$(PRY_VERSION).ps

$(PRINT_DIR)/$(PROYECTO).pdf: $(PRINT_DIR)/$(PROYECTO).ps
	ps2pdf $(PRINT_DIR)/$(PROYECTO).ps $@

$(PRINT_DIR)/$(PROYECTO).ps: $(PRINT_DIR)/$(PROYECTO).dvi
	cd $(PRINT_DIR) && dvips -o $(PROYECTO).ps $(PROYECTO).dvi

$(PRINT_DIR)/$(PROYECTO).dvi: $(PRINT_DIR)/$(PROYECTO).tex
	-cd $(PRINT_DIR); $(JADETEX) $(PROYECTO).tex; $(JADETEX) $(PROYECTO).tex; $(JADETEX) $(PROYECTO).tex

$(PROYECTO)-4.1.sgml: $(PROYECTO).xml
	sed -e "s|DOCTYPE \\([A-Za-z0-9_]*\\) [-\" A-Za-z0-9_/.]*|DOCTYPE \\1 PUBLIC \"-//OASIS//DTD DocBook V4.1//EN\"|g" $(PROYECTO).xml > $(PROYECTO)-4.1.sgml

$(PRINT_DIR)/$(PROYECTO).tex: $(INDEX) $(SOURCES) $(IMAGES:.png=.eps) $(DSSSL_PRINT) $(PROYECTO)-4.1.sgml
	mkdir -p $(PRINT_DIR)
	for i in $(IMAGES:.png=.eps) ; do cp -f $$i $(PRINT_DIR)/`basename $$i`; done

	-bp=`pwd`; cd $(PRINT_DIR) && rm -f *.aux *.log && $(JADE) -V tex-backend -D$(DOCBOOK_DSSSL_PRINT) -o $(PROYECTO).tex -t tex -d $$bp/$(DSSSL_PRINT) $$bp/$(PROYECTO)-4.1.sgml
	rm -f $(PROYECTO)-4.1.sgml


$(INDEX): $(INDEX).m
		echo "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>" > $@
	        cat $(INDEX).m >> $@

$(INDEX).m: HTML.index.m
	        perl -S $(COLLATEINDEX) -o $@ HTML.index.m

HTML.index.m: $(PROYECTO)-4.1.sgml $(SOURCES)
	echo $(COLLATEINDEX);
	if (test ! -f $(INDEX)) then { \
        perl -S $(COLLATEINDEX) -N -o $(INDEX); \
	} fi;
	-cd $(HTML_DIR) && rm -f * && $(JADE) -D .. -D $(DOCBOOK_DSSSL_HTML) -t sgml -ihtml -V html-index -d docbook.dsl $(PROYECTO)-4.1.sgml 
	mv html/HTML.index HTML.index.m

.SUFFIXES: .eps .png

.jpg.eps:
	convert $< EPS:$@

.png.eps:
	convert $< EPS:$@

